@@ -92,7 +92,7 @@ SDES = Field(..., name='Place')
 DLMC = Field(..., name='Manual shipment scheduling allowed')
 DLAC = Field(..., name='Ignore deadline when connecting dely no')
 TSID = Field('', name='Transportation service ID')
-CHB1 = Field(0, name='Yes/No', max_digits=1)
+CHB1 = Field(0, name='Yes/No')
 CMNT = Field(..., name='Comment') 
 
 
